@@ -29,6 +29,7 @@ class SignalParalleLauncher():
         self.runs = []
         self.totalRow = 0
         self.instantiateTable()
+        self.instantiateSignalTable()
         self.empty_runs_to_investigate = []
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
 
@@ -41,6 +42,25 @@ class SignalParalleLauncher():
         for meArg in self.args:
              toRun(*meArg)
 
+    def instantiateSignalTable(self):
+        sqliteConnection = None
+        try:
+            sqliteConnection = sqlite3.connect(self.db_path)
+            sqlite_create_table_query = '''CREATE TABLE parallel_signal (
+                                        effective_date date PRIMARY KEY);'''
+            cursor = sqliteConnection.cursor()
+            print("Successfully Connected to SQLite")
+            cursor.execute(sqlite_create_table_query)
+            sqliteConnection.commit()
+            print("SQLite table created")
+            cursor.close()
+        except sqlite3.Error as error:
+            print("Error while creating a sqlite table", error)
+        finally:
+            if (sqliteConnection):
+                sqliteConnection.close()
+                print("sqlite connection is closed")
+
     def instantiateTable(self):
         sqliteConnection = None
         try:
@@ -98,6 +118,27 @@ class SignalParalleLauncher():
                 sqliteConnection.close()
                 print("sqlite connection is closed")  # adding the column
 
+    def insertSignals(self, run, values):
+        sqliteConnection = None
+        try:
+            success = True
+            sqliteConnection = sqlite3.connect(self.db_path)
+            cursor = sqliteConnection.cursor()
+            for i, v in values.iteritems():
+                sqlite_insert_query = """INSERT INTO 'parallel_signal' ('effective_date', '""" + run + """') VALUES ('""" + str(
+                    i) + """','""" + str(v) + """');"""
+                cursor.execute(sqlite_insert_query)
+            sqliteConnection.commit()
+            cursor.close()
+        except sqlite3.Error as error:
+            print("Error while working with SQLite", error)
+            success = False
+        finally:
+            if (sqliteConnection):
+                sqliteConnection.close()
+                print("The Sqlite connection is closed")
+        return success
+
     def insertResults(self, run, values):
         sqliteConnection = None
         try:
@@ -119,6 +160,24 @@ class SignalParalleLauncher():
                 print("The Sqlite connection is closed")
         return success
 
+    def updateSignals(self, run, values):
+        sqliteConnection = None
+        try:
+            sqliteConnection = sqlite3.connect(self.db_path)
+            cursor = sqliteConnection.cursor()
+            for i, v in values.iteritems():
+                sqlite_update_query = """UPDATE 'parallel_signals' set '""" + run + """' = '""" + str(
+                    v) + """' where effective_date = '""" + str(i) + """'"""
+                cursor.execute(sqlite_update_query)
+            sqliteConnection.commit()
+            cursor.close()
+        except sqlite3.Error as error:
+            print("Error while working with SQLite", error)
+        finally:
+            if (sqliteConnection):
+                sqliteConnection.close()
+                print("The Sqlite connection is closed")
+
     def updateResults(self, run, values):
         sqliteConnection = None
         try:
@@ -188,6 +247,30 @@ class SignalParalleLauncher():
         if not success :
             self.updateResults(run, values)
 
+    def addSignals(self, run, values):
+        success = self.insertSignals(run,values)
+        if not success :
+            self.updateSignals(run, values)
+
+    def addSignal(self,run):
+        sqliteConnection = None
+        try:
+            sqliteConnection = sqlite3.connect(self.db_path)
+            sqlite_create_table_query = 'alter table parallel_signal add column ' + run + ' real'
+            cursor = sqliteConnection.cursor()
+            print("Successfully Connected to SQLite")
+            cursor.execute(sqlite_create_table_query)
+            sqliteConnection.commit()
+            print("SQLite table created")
+            cursor.close()
+            self.runs.append(run)
+        except sqlite3.Error as error:
+            print("Error while creating a sqlite table", error)
+        finally:
+            if (sqliteConnection):
+                sqliteConnection.close()
+                print("sqlite connection is closed")  # adding the column
+
     def addRun(self,run):
         sqliteConnection = None
         try:
@@ -207,12 +290,21 @@ class SignalParalleLauncher():
                 sqliteConnection.close()
                 print("sqlite connection is closed")  # adding the column
 
+    def saveAll(self,run, strat_results_df):
+        self.saveResults(run, strat_results_df['reconstituted_perf'])
+        self.saveSignals(run, strat_results_df['reconstituted_perf'])
+
     def saveResults(self, run, strat_results_df):
         self.addRun(run)
         #self.addRunPerf(run)
         #self.addRunTurnOver(run)
         self.addResults(run, strat_results_df)
 
+    def saveSignals(self, run, strat_results_df):
+        self.addSignal(run)
+        #self.addRunPerf(run)
+        #self.addRunTurnOver(run)
+        self.addSignals(run, strat_results_df)
 
     def checkRunExistence(self,run):
         sqliteConnection = None
