@@ -77,9 +77,9 @@ class AbstractRunner(ABC):
             saver = signal_result_analyzer.ParallelRunResultAnalyzer(drop_token=drop_token,
                                                                      local_root_directory=local_root_directory, user=user,
                                                                      db_path_suffix=self.db_path_suffix)
-            self.precomputed_results_df = saver.analyzeAllRunResults()
+            self.precomputed_results_df, self.precomputed_signals_df = saver.analyzeAllRunResults()
         else:
-            self.precomputed_results_df = None
+            self.precomputed_results_df, self.precomputed_signals_df  = None, None
 
     @abstractmethod
     def runTrial(self,saver,  seed, trigger, signal_type, idios_string, transaction_costs, normalization):
@@ -127,8 +127,15 @@ class EnsemblingSignalRunner(AbstractRunner):
                                               lambda x: signal_generation_method_to_call(data=x, **params), trigger)
                     hourly_df = signal_utility.reconstitute_signal_perf(data = hourly_df, transaction_cost = transaction_costs, normalization = normalization)
             else :
-                hourly_df = self.precomputed_results_df[me_signal]
-
+                if self.add_turn_over:
+                    raise Exception('to add turn over, you have to recompute all')
+                hourlyperf_df = self.precomputed_results_df[me_signal]
+                hourlysig_df = self.precomputed_signals_df[me_signal]
+                hourlyperf_df = hourlyperf_df.to_frame()
+                hourlyperf_df.columns = ['close']
+                hourlysig_df = hourlysig_df.to_frame()
+                hourlysig_df.columns = ['signal']
+                hourly_df = hourlyperf_df.merge(hourlysig_df, left_index = True, right_index = True)
 
             if cumulated_signals is None:
                 if self.add_turn_over:
